// #include <boost/thread/thread.hpp>
// #include <boost/thread/mutex.hpp>
// #include <boost/thread/condition.hpp>
#include "channel.h"

channel::
channel() : started_(false), stopped_(false) {}

void
channel::
signal_start()
{
    scoped_lock lock(start_mtx_);
    started_ = true;
    start_sem_.notify_one();
}

void
channel::
signal_stop()
{
    scoped_lock lock(stop_mtx_);
    stopped_ = true;
    stop_sem_.notify_one();
}

void
channel::
wait_start()
{
    scoped_lock lock(start_mtx_);
    while (!started_)
        start_sem_.wait(lock);
    started_ = false;
}

void
channel::
wait_stop()
{
    scoped_lock lock(stop_mtx_);
    while (!stopped_)
        stop_sem_.wait(lock);
    stopped_ = false;
}

bool
channel::
stopped()
{
    scoped_lock lock(stop_mtx_);
    return stopped_;
}
